package com.competition.adapter.app;

import com.competition.IAdapter;
import com.competition.adapter.BaseAdapter;
import com.competition.bean.DcFootSchedule;
import com.competition.bean.DcFootSclass;
import com.competition.bean.DcFootTeam;
import com.competition.bean.plus.DcFootScorePlus;
import com.competition.cache.FootCache;
import com.competition.constant.Constants;
import com.competition.service.IDcFootScheduleService;
import com.competition.service.IDcFootSclassService;
import com.competition.service.plus.IDcFootScorePlusService;
import com.competition.utils.SpringUtils;
import com.competition.utils.Utils;
import com.competition.utils.xml.parse.ByteCodeUtil;
import com.competition.utils.xml.parse.XmlBean;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Component;

@Component
public class App0032Adapter extends BaseAdapter implements IAdapter {

   @Resource
   private IDcFootScheduleService footScheduleService;
   @Resource
   private IDcFootScorePlusService scorePlusService;
   @Resource
   private IDcFootSclassService sclassService;


   public XmlBean execute(XmlBean xmlBean) {
      XmlBean requestBean = xmlBean.getFirst("request");
      XmlBean queryBean = requestBean.getFirst("query");
      Long scheduleId = Utils.formatLong(queryBean.attribute("scheduleId"));
      Long sclassId = Utils.formatLong(queryBean.attribute("sclassId"));
      if(scheduleId == null && sclassId == null) {
         return this.returnErrorCodeBody("0003");
      } else {
         try {
            DcFootSchedule e = null;
            if(sclassId == null) {
               e = this.footScheduleService.getDcFootSchedule(scheduleId);
               if(e == null) {
                  return this.returnErrorCodeBody("9000");
               }
            }

            DcFootSclass sclass = this.sclassService.getDcFootSclassBySclassId(sclassId != null?sclassId:e.getSclassId());
            if(sclass == null) {
               return this.returnErrorCodeBody("9000");
            } else {
               DcFootScorePlus scorePlusParam = new DcFootScorePlus();
               scorePlusParam.setSclassId(sclass.getSclassId());
               scorePlusParam.setSeason(sclass.getCurrMatchSeason());
               scorePlusParam.setHomeOrGuest(Integer.valueOf(Constants.HOST_TYPE_MIDDLE.intValue()));
               scorePlusParam.setUpOrDown(Integer.valueOf(Constants.HALF_TYPE_All.intValue()));
               List scorePlusList = this.scorePlusService.queryScorePlusList(scorePlusParam);
               return this.buildXmlBean(scorePlusList, sclass, e);
            }
         } catch (Exception var10) {
            var10.printStackTrace();
            return this.returnErrorCodeBody("0999");
         }
      }
   }

   private XmlBean buildXmlBean(List scorePlusList, DcFootSclass sclass, DcFootSchedule schedule) {
      int maxRound = 0;
      StringBuffer sb = new StringBuffer();
      sb.append("<body>");
      sb.append("<list size=\"\">");
      if(scorePlusList != null && scorePlusList.size() > 0) {
         Iterator var7 = scorePlusList.iterator();

         while(var7.hasNext()) {
            DcFootScorePlus scorePlus = (DcFootScorePlus)var7.next();
            DcFootTeam team = (DcFootTeam)FootCache.CACHE_ALL_TEAM.get(scorePlus.getTeamId().toString());
            sb.append("<detail>");
            sb.append("<rank>");
            sb.append(scorePlus.getRank());
            sb.append("</rank>");
            sb.append("<team>");
            sb.append(Utils.addCDATA(team != null?team.getNameJ():""));
            sb.append("</team>");
            sb.append("<logo>");
            sb.append(Utils.addCDATA(team != null?team.getFlag():""));
            sb.append("</logo>");
            sb.append("<teamId>");
            sb.append(scorePlus.getTeamId());
            sb.append("</teamId>");
            sb.append("<win>");
            sb.append(scorePlus.getWin());
            sb.append("</win>");
            sb.append("<flat>");
            sb.append(scorePlus.getFlat());
            sb.append("</flat>");
            sb.append("<lose>");
            sb.append(scorePlus.getLose());
            sb.append("</lose>");
            sb.append("<goal>");
            sb.append(scorePlus.getGs());
            sb.append("</goal>");
            sb.append("<ungoal>");
            sb.append(scorePlus.getGa());
            sb.append("</ungoal>");
            sb.append("<score>");
            sb.append(scorePlus.getScore());
            sb.append("</score>");
            sb.append("<round>");
            sb.append(scorePlus.getTotalMatch());
            sb.append("</round>");
            sb.append("<group>");
            sb.append(scorePlus.getGroupName());
            sb.append("</group>");
            sb.append("</detail>");
            if(scorePlus.getTotalMatch().intValue() > maxRound) {
               maxRound = scorePlus.getTotalMatch().intValue();
            }
         }

         if(scorePlusList.size() == 1) {
            sb.append("<detail></detail>");
         }

         sb.append("<sclass>");
         sb.append(Utils.addCDATA(sclass.getNameJ()));
         sb.append("</sclass>");
         sb.append("<kind>");
         sb.append(sclass.getKind());
         sb.append("</kind>");
         sb.append("<season>");
         sb.append(Utils.addCDATA(schedule == null?sclass.getCurrMatchSeason():schedule.getMatchSeason()));
         sb.append("</season>");
         sb.append("<round>");
         sb.append(maxRound);
         sb.append("</round>");
      }

      sb.append("</list>");
      sb.append("</body>");
      return ByteCodeUtil.xmlToObject(sb.toString());
   }

   public static void main(String[] args) {
      String string = "<root><request><query sclassId=\"36\" issue=\"20150924\" sn=\"001\" company=\"3\"></query></request></root>";
      IAdapter adapter = (IAdapter)SpringUtils.getBean("app0032Adapter");
      System.out.println(adapter.execute(ByteCodeUtil.xmlToObject(string)).toString());
   }
}
